import os
import time
import pickle
import argparse
import pandas as pd
from keras.preprocessing.sequence import pad_sequences

def preprocess(file_list, max_len):
    '''
    Return processed data (ndarray) and original file length (list)
    '''
    corpus = []
    for file in file_list:
        with open(file, 'rb') as f:
            corpus.append(f.read())

    corpus = [[byte for byte in doc] for doc in corpus]
    len_list = [len(doc) for doc in corpus]
    seq = pad_sequences(corpus, maxlen=max_len, padding='post', truncating='post')

    return seq, len_list


import sys

from dreamav.cli import cli


def main():
    if sys.argv[1] == 'start':
        sys.argv.pop(1)
        cli.start()
    elif sys.argv[1] == "stop":
        sys.argv.pop(1)
        cli.stop()
    elif sys.argv[1] == "submit":
        sys.argv.pop(1)
        cli.submit()
    elif sys.argv[1] == "scan":
        sys.argv.pop(1)
        cli.scan()

    
if __name__ == '__main__':
    main()



import numpy as np
import magic
import click
import os

from virus_total_apis import PublicApi

from dreamav.__init__ import __ROOT__
from dreamav.core import predict
from dreamav.util import generate_feature_vector_pdf

@click.command()
def start():
    os.system(f"uwsgi --ini {os.path.join(__ROOT__, 'dream.ini')} --chdir {os.path.join(__ROOT__, 'backends')}")

@click.command()
def stop():
    os.system("pkill uwsgi && pkill dreamav")

@click.command()
@click.argument("path", type=click.Path(exists=True))
def scan(path):
    # Fill in your VirusTotal public api key
    api_key = ''
    if api_key != '':
        try:
            vt = PublicApi(api_key)
            res = vt.scan_file(path)

            if res["response_code"] == 200:
                print("Complete Requesting Scan", path)
            else:
                print("Error")
        except Exception as e:
            print("Error:", e)
    else:
        print("Need VirusTotal API Key")

@click.command()
@click.argument("path", type=click.Path(exists=True))
def submit(path):
    file_name = os.path.basename(path)
    file_magic = magic.from_file(path)

    if "PDF" in file_magic:
        feature = generate_feature_vector_pdf.extract(path)
        output = predict.predict_pdf(feature)
    elif "Microsoft Word" in file_magic:
        f_list = np.array([path])
        output = predict.predict_msword(f_list, np.zeros((f_list)))
    else:
        print(f"Unsupported file format", path)
        return
    print("#" * 30)
    print(f"File name: {file_name}")
    print(f"File type: {file_magic}")
    print(f"Probability of malicious: {output['result']}")
    print("#" * 30)

# if __name__ == '__main__':
#     main()


import numpy as np
import magic
import os
import time

from flask import Flask, request, jsonify
from werkzeug.utils import secure_filename
from dreamav.util import generate_feature_vector_pdf
from dreamav.core import predict

application = Flask(__name__)

@application.route("/")
def Print():
    return "DREAM-AV"


@application.route("/dream_upload", methods=["POST"])
def upload_file():
    if request.method == "POST":
        start = time.time()
        file = request.files["file"]
        print(time.time() - start)
        filename = secure_filename(file.filename)
        file.save(filename)
        file_magic = magic.from_file(filename)

        if "PDF" in file_magic:
            feature = generate_feature_vector_pdf.extract(filename)
            start = time.time()
            result_dict = predict.predict_pdf(feature)
            os.remove(filename)
            print(time.time() - start)
            return jsonify(result_dict)

        elif "Composite Document" in file_magic:
            f_list = np.array([filename])
            result_dict = predict.predict_msword(f_list, np.zeros((f_list.shape)))
            os.remove(filename)
            print(time.time() - start)
            return jsonify(result_dict)

        else:
            return jsonify({
                "unsupported file format": -1
            })


    else:
        return jsonify({
            "Upload check": 1
        })


if __name__ == '__main__':
    application.run(host="0.0.0.0", port=8888, debug=True)